@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2021, kachelaqa <kachelaqa@gmail.com>
+# Copyright (C) 2010-2022, kachelaqa <kachelaqa@gmail.com>
 
 import sys, os, re, glob, copy, errno, socket, json
 import urllib.request, urllib.error, http.client
@@ -15,8 +15,8 @@ from pkgbrowser.enum import State, Source
 
 
 AUR_DOM = os.environ.get('AUR_DOM', 'https://aur.archlinux.org')
-AUR_RPC = AUR_DOM + '/rpc.php'
-AUR_HTM = AUR_DOM + '/packages.php'
+AUR_RPC = AUR_DOM + '/rpc'
+AUR_HTM = AUR_DOM + '/packages'
 AUR_SRC = AUR_DOM + '/cgit/aur.git/plain/.SRCINFO'
 ALA_DOM = os.environ.get('ALA_DOM', 'https://archive.archlinux.org')
 ALA_LIST = ALA_DOM + '/packages/%s/%s/'
